pub struct LockFile {
pub version: u32,
pub packages: Vec<LockedPackage>,
}Expand description
The lock file format for grove.lock.
Fields
version: u32Schema version for future compatibility.
packages: Vec<LockedPackage>All locked packages (including transitive dependencies).
Implementations
Sourceimpl LockFile
impl LockFile
Sourcepub fn load(path: &Path) -> Result<Self, PackageError>
pub fn load(path: &Path) -> Result<Self, PackageError>
Load a lock file from disk.
Sourcepub fn find(&self, name: &str) -> Option<&LockedPackage>
pub fn find(&self, name: &str) -> Option<&LockedPackage>
Find a package by name.
Sourcepub fn package_map(&self) -> HashMap<&str, &LockedPackage>
pub fn package_map(&self) -> HashMap<&str, &LockedPackage>
Build a map of package name to locked package.
Sourcepub fn matches_dependencies(
&self,
deps: &HashMap<String, DependencySpec>,
) -> bool
pub fn matches_dependencies( &self, deps: &HashMap<String, DependencySpec>, ) -> bool
Check if the lock file matches the given dependencies.
Sourcepub fn in_dependency_order(&self) -> Vec<&LockedPackage>
pub fn in_dependency_order(&self) -> Vec<&LockedPackage>
Return packages in dependency order (dependencies first).